@@ -4,17 +4,21 @@ import os
 import re
 import sys
 import json
+import shutil
 import argparse
 import subprocess
 
 
-__VERSION__ = '0.0.6'
+__VERSION__ = '0.0.7'
 
 
-def cmd(string, cwd=os.getcwd(), verbose=True):
+def cmd(string, cwd=os.getcwd(), verbose=True, shell=False):
     """Wraps Popen"""
 
-    process = subprocess.Popen(string.split(' '), cwd=cwd, stdout=subprocess.PIPE)
+    if not shell:  # Split command up by spaces
+        string = string.split(' ')
+
+    process = subprocess.Popen(string, cwd=cwd, stdout=subprocess.PIPE, shell=shell)
     to_string = process.communicate()[0].decode('utf-8')
     if verbose:
         print(to_string)
@@ -27,9 +31,12 @@ def filter_none(args):
     return list(filter(lambda x: x != None, args))
 
 
-def filter_subtrees(prefixes, subtrees):
+def filter_subtrees(prefixes, subtrees, invert=False):
     """Takes the json list of subtrees and returns only the ones specified (by prefix)"""
 
+    if invert:
+        return list(filter(lambda subt: subt['prefix'] not in prefixes, subtrees))
+
     return list(filter(lambda subt: subt['prefix'] in prefixes, subtrees))
 
 
@@ -152,6 +159,21 @@ def merge(args):
     pass
 
 
+def remove(args):
+    parser = argparse.ArgumentParser()
+    parser.add_argument('--all', action='store_true', help='Remove all subtrees')
+    parser.add_argument('prefixes', nargs='*', default=[], help='Subtree prefixes/paths')
+    args = parser.parse_args(args)
+
+    subtrees = load_json()
+    fsubtrees = filter_subtrees(all_prefixes(subtrees) if args.all else args.prefixes, subtrees)
+
+    for subt in subtrees:
+        cmd('git rm -rf {}'.format(subt['prefix']))
+
+    add_subtree_to_json(filter_subtrees(all_prefixes(fsubtrees), subtrees, invert=True))
+
+
 def ls(args):
     """List existing submodules using git log"""
 
@@ -185,6 +207,8 @@ ACTIONS = {
     'push': push,
     'reset': reset,
     'merge': merge,
+    'remove': remove,
+    'rm': remove,
     'ls': ls,
     'graph': graph,
     'help': cs_help,
